Composition
===========

.. container:: subclasses

    *Subclasses*

    .. toctree::
       :maxdepth: 1

       AutodiffComposition
       CompositionFunctionApproximator
    |

.. container:: related

    *Related*

    * `NodeRoles <NodeRole>`

    .. toctree::
       :maxdepth: 1

       Pathway
       Scheduling
       Visualization

.. automodule:: psyneulink.core.compositions.composition
   :members: Composition, NodeRole
   :private-members:
   :exclude-members: Parameters, show_structure, CompositionError
